#
#
# $Id$
#
# This program is free software; you can redistribute it and/or 
# modify it under the terms of the GNU General Public License, version 2.
#
# Infobrowser support for the BBC Whats On  items
#
package Plugins::InfoBrowserAddons::RecentlyPlayedClassicFM::RecentlyPlayedClassicFMParser;

# Parser for www.sky.fm's recently played pages

use strict;

use Slim::Utils::Log;

use HTML::PullParser;
use HTML::Entities;
use Date::Parse qw(str2time);
use Data::Dumper;

my $log = logger('plugin.infobrowser');


sub getDisplayName { 'Recently Played SkyFM ' };

sub getnexttag
{
  my $t;
  my $p         = shift;
  my $searchtag = shift;
  my $exittag   = shift ;

  for (;;) {
     $t = $p->get_token();
     return undef unless (defined($t));
     return $t if ( $t->[1] eq $searchtag) ;
     return $t if ( defined ($exittag) && $t->[1] eq $exittag) ;
  }
}


sub cleanup
{
  my $str = shift;
  return undef unless defined ($str); 
  
  $str =~ s/\n/ /g;  # change LF to space
  $str =~ s/\r//g;   # Get rid of CR if any.
  $str =~ s/<br>//g; # Get rid of HTML <br> if any.
  $str =~ s/<br \/>//g; # Get rid of HTML <br> if any.
  $str =~ s/<BR>//g; # Get rid of HTML <BR> if any.
  $str =~ s/<B>//g; # Get rid of HTML <B> if any.
  $str =~ s/<\/B>//g; # Get rid of HTML </B> if any.
  $str =~ s/&nbsp;/ /g; # replace HTML &nbsp if any.

# strip whitespace from beginning and end

  $str =~ s/^\s*//; 
  $str =~ s/\s*$//; 
  

  return $str;
}



sub parse
{
	my $class  = shift;
	my $http   = shift;

	my $params = $http->params('params');
	my $url    = $params->{'url'};
	my $title  = $params->{'text'};
	my @list;
#	my @revlist;
	my $token;
	my ( $playeddate, $playedtime , $playedsong,  $playedartist);

	my $p = HTML::PullParser->new(api_version => 3, doc => ${$http->contentRef},
		      	    	  start => 'event, tag, attr,  skipped_text',
			    	  end   => 'event, tag, dtext, skipped_text',
			          report_tags => [qw ( td tr table div a)]);

    while($token = getnexttag($p,"div")) {

        next unless defined($token->[2]->{class});
        last if $token->[2]->{class} eq "playlist";
    }
     $log->debug(" Found start of playlist ") if (defined($token));

	$token = getnexttag($p,"table");
	$token = getnexttag($p,"tr");


#   <tr>
#        <td align="left" valign="top" class="tablePadding">08/02/08</td>
#        <td align="left" valign="top" class="tablePadding">5:53 am</td>
#        <td align="left" valign="top" class="tablePadding">Alexandre Desplat</td>
#        <td align="left" valign="top">The Golden Compass - Epilogue</td>
#        <td align="center" valign="top">
#               <a href="javascript:openplaylist('164004')"><img src="images/play-moreinfo.gif" width="19" height="19">
#               </a>
#        </td>
#  </tr>

	while ($token = getnexttag($p,"tr","/table")) {
		last if ($token->[1] eq "/table");

		$token = getnexttag($p,"td");

		$token = getnexttag($p,"/td");
		$playeddate = cleanup ($token->[3] ) ;

		$token = getnexttag($p,"/td");
		$playedtime = cleanup ($token->[3] ) ;

		$token = getnexttag($p,"/td");
		$playedartist = cleanup ($token->[3] ) ;

		$token = getnexttag($p,"/td");
		$playedsong = cleanup ($token->[3] ) ;

	        $log->debug( "date=$playeddate  $playedtime artist=$playedartist song=$playedsong ");

	         push @list,{   'name'   =>  "$playedsong   by  $playedartist",
				'description'   =>  "Track:$playedsong \nComposer:$playedartist \nPlayed at: $playedtime  $playeddate",
	 	};

		$token = getnexttag($p,"/tr");
	}		

#	@revlist = reverse @list;
#print "=====================================================================\n";
#print Dumper(@list);
#print "=====================================================================\n";
#print Dumper(@revlist);

	return {
		'type'  => 'opml',
		'title' => "$title",
		'name' => "RecentlyPlayedClassicFM - parsed",
		'items' => [ reverse @list],
	};

}


# Local Variables:
# tab-width:4
# indent-tabs-mode:t
# End:

1;
